@@ -142,7 +142,8 @@ def main():
 
     if os.path.isfile(".qgis-plugin-ci"):
         # We read the .qgis-plugin-ci file
-        arg_dict = yaml.safe_load(open(".qgis-plugin-ci"))
+        with open(".qgis-plugin-ci", "r", encoding="utf8") as f:
+            arg_dict = yaml.safe_load(f)
     else:
         config = configparser.ConfigParser()
         config.read("setup.cfg")
